#!/bin/sh

# NB: The .alhConfig scripts permit ALH to start MEDM, so we need to have
# the MEDM setups done as well.

# Where are we?
cd `dirname "$0"`
TOP=`/bin/pwd`

if [ "`uname -sp`" = "Darwin powerpc" ]
then
    ARCH=darwin-ppc
else
    echo "This script runs on Darwin (MacOS) only"
    exit 1
fi

X11='/usr/X11R6/bin'
BIN="$TOP/bin/$ARCH"
export DYLD_LIBRARY_PATH="$TOP/lib/$ARCH"

# Disable external network activity
export EPICS_CA_AUTO_ADDR_LIST=NO
export EPICS_CA_ADDR_LIST=localhost

# Point MEDM at our directory containing .adl and font alias files
export EPICS_DISPLAY_PATH="$TOP/medm"

if [ -z "$DISPLAY" ]
then
    # NB: This value for DISPLAY isn't always correct...
    export DISPLAY=":0.0"
fi

if $X11/xset -q >& /dev/null
then
    :
else
    open /Applications/Utilities/X11.app
    sleep 2
    until $X11/xset -q >&/dev/null
    do
        sleep 2
    done
fi

# X11 font configuration for MEDM
if [ -f "$EPICS_DISPLAY_PATH/fonts.alias" -a -z "`$X11/xlsfonts -fn '*widgetdm*' 2>/dev/null`" ]
then
    $X11/xset fp+ "$EPICS_DISPLAY_PATH" 2>/dev/null
    sleep 1
fi

# Substitute our $USER's name in the alhConfig files
cd "$TOP/alh"
if [ ! -f linac.$USER.alhConfig ]
then
    sed -e "s/@USER@/$USER/g" linac.alhConfig.in >linac.$USER.alhConfig
fi
if [ ! -f linac_final.$USER.alhConfig ]
then
    sed -e "s/@USER@/$USER/g" linac_final.alhConfig.in >linac_final.$USER.alhConfig
fi

# Run ALH
exec "$BIN/alh"
